//
//  TextView.swift
//  Write!
//
//  Created by Keith Lander on 31/10/2019.
//  Copyright © 2019 Keith Lander. All rights reserved.
//

import SwiftUI
import Proton

struct AttributedTextView: UIViewRepresentable {
    var textFile: TextFile
    var size: CGSize

    init(textSize: CGSize)
    {
        self.size = textSize
        self.textFile = TextFile.add(name:"Test")!
    }

    func makeCoordinator() -> Coordinator {
        return Coordinator(self,
                           textFile: textFile)
    }

    func makeUIView(context: Context) -> EditorView {
        let editor = context.coordinator.setupTextView(with: size)
        editor.delegate = context.coordinator as EditorViewDelegate
        return editor
    }

    func updateUIView(_ uiTextView: EditorView, context: Context) {
    }

    class Coordinator: EditorViewDelegate {
        var parent: AttributedTextView
        var enterCount = 0
        var textView: EditorView?

        init(_ textView: AttributedTextView,
             textFile: TextFile)
        {
            self.parent = textView
        }

        func setupTextView(with size: CGSize) -> EditorView {
            textView = EditorView(frame: CGRect(origin: CGPoint.zero, size: size))
            guard let textView = textView else {
                fatalError()
            }
            textView.isEditable = true
            textView.isScrollEnabled = true
            textView.isUserInteractionEnabled = true
            textView.becomeFirstResponder()
            return textView
        }
                        
        func editor(_ editor: EditorView,
                    didChangeSelectionAt range: NSRange,
                    attributes: Attributes,
                    contentType: EditorContent) 
        {
            print("selection")
        }

        func editor(_ editor: EditorView, didChangeTextAt range: NSRange) {
            editor.isScrollEnabled = true
            editor.scrollRangeToVisible(range)
        }
    }
}
